@@ -24,7 +24,8 @@ ghypMean <- function(mu = 0, delta = 1, alpha = 1, beta = 0, lambda = 1,
 
   gamma <- sqrt(alpha^2 - beta^2)
 
-  mu + delta*beta*besselRatio(delta*gamma, lambda, 1)/gamma
+  mn <- mu + delta*beta*besselRatio(delta*gamma, lambda, 1)/gamma
+  mn
 } ## End of ghypMean()
 
 ### Function to calculate the theoretical variance of a
@@ -46,7 +47,7 @@ ghypVar <- function(mu = 0, delta = 1, alpha = 1, beta = 0, lambda = 1,
     stop(errMessage)
 
   var <- ghypMom(2, param = param, momType = "central")
-  return(var)
+  var
 } ## End of ghypVar()
 
 ### Function to calculate the theoretical skewness of a
@@ -69,7 +70,7 @@ ghypSkew <- function(mu = 0, delta = 1, alpha = 1, beta = 0, lambda = 1,
 
   skew <- ghypMom(3, param = param, momType = "central")/
                  (ghypVar(param = param)^(3/2))
-  return(skew)
+  skew
 } ## End of ghypSkew()
 
 ### Function to calculate the theoretical kurtosis of a
@@ -92,7 +93,7 @@ ghypKurt <- function(mu = 0, delta = 1, alpha = 1, beta = 0, lambda = 1,
 
   kurt <- ghypMom(4, param = param, momType = "central")/
                  (ghypVar(param = param)^2) - 3
-  return(kurt)
+  kurt
 } ## End of ghypKurt()
 
 ### Function to calculate the theoretical mode point of a
@@ -129,6 +130,6 @@ ghypMode <- function(mu = 0, delta = 1, alpha = 1, beta = 0, lambda = 1,
   range <- c(xLow, xHigh)
   optResult <- optimize(f = modeFun, interval = range, maximum = TRUE)
   mode <- optResult$maximum
-  return(mode)
+  mode
 } ## End of ghypMode()
 
